diff --git a/notebooks/Jungfrau/Jungfrau_dark_analysis_all_gains_burst_mode_NBC.ipynb b/notebooks/Jungfrau/Jungfrau_dark_analysis_all_gains_burst_mode_NBC.ipynb
index 3b2aa945f498c7246a6d1a207c89a7d6cfd578b0..e9e48e6050e5f856ed118cf776c29815525c0d1b 100644
--- a/notebooks/Jungfrau/Jungfrau_dark_analysis_all_gains_burst_mode_NBC.ipynb
+++ b/notebooks/Jungfrau/Jungfrau_dark_analysis_all_gains_burst_mode_NBC.ipynb
@@ -91,8 +91,9 @@
     "from cal_tools.ana_tools import save_dict_to_hdf5\n",
     "from cal_tools.enums import (\n",
     "    BadPixels,\n",
+    "    JungfrauGainMode,\n",
     "    JungfrauSettings,\n",
-    ")\n",
+    "    )\n",
     "from cal_tools.tools import (\n",
     "    get_dir_creation_date,\n",
     "    get_pdu_from_db,\n",
@@ -116,13 +117,9 @@
     "gains = [0, 1, 2]\n",
     "\n",
     "fixed_settings = [\n",
-    "    JungfrauSettings.FIX_GAIN_1.name,\n",
-    "    JungfrauSettings.FIX_GAIN_2.name,\n",
-    "    ]\n",
+    "    JungfrauGainMode.FIX_GAIN_1.value, JungfrauGainMode.FIX_GAIN_2.value]\n",
     "dynamic_settings = [\n",
-    "    JungfrauSettings.FORCE_SWITCH_HG1.name,\n",
-    "    JungfrauSettings.FORCE_SWITCH_HG2.name,\n",
-    "    ]\n",
+    "    JungfrauGainMode.FORCE_SWITCH_HG1.value, JungfrauGainMode.FORCE_SWITCH_HG2.value]\n",
     "\n",
     "creation_time = None\n",
     "if use_dir_creation_date:\n",
@@ -197,14 +194,13 @@
     "                  f'storage cell start: {sc_start:02d}')\n",
     "    else:\n",
     "        gain_mode = ctrl_data.get_gain_mode()\n",
-    "\n",
-    "        med_low_settings.append(JungfrauSettings(ctrl_data.run_mode).name)\n",
+    "        med_low_settings.append(ctrl_data.run_mode)\n",
     "\n",
     "# A transperent workaround for old raw data with wrong/missing medium and low settings\n",
     "if med_low_settings == [None, None]:\n",
     "    print(\"WARNING: run.settings is not stored in the data to read. \"\n",
     "          f\"Hence assuming gain_mode = {gain_mode} for adaptive old data.\")\n",
-    "elif med_low_settings == [\"dynamicgain\", \"forceswitchg1\"]:\n",
+    "elif med_low_settings == [\"dynamic\", \"forceswitchg1\"]:\n",
     "    print(f\"WARNING: run.settings for medium and low gain runs are wrong {med_low_settings}. \"\n",
     "          f\"This is an expected bug for old raw data. Setting gain_mode to {gain_mode}.\")\n",
     "# Validate that low_med_settings is not a mix of adaptive and fixed settings.\n",
diff --git a/src/cal_tools/enums.py b/src/cal_tools/enums.py
index 7231c570031fb843f40a080db1ec0421fcae565c..7f50f388b9153f84d6f41a8050cecfd1eed77127 100644
--- a/src/cal_tools/enums.py
+++ b/src/cal_tools/enums.py
@@ -1,4 +1,4 @@
-from enum import Enum, IntEnum, IntFlag, EnumMeta
+from enum import Enum, IntEnum, IntFlag
 
 
 class BadPixels(IntFlag):
@@ -47,44 +47,17 @@ class AgipdGainMode(IntEnum):
 
 
 class JungfrauSettings(Enum):
-    """Jungfrau run gain settings.
+    """Jungfrau run gain settings."""
+    # old setting, new setting, new mode
+    GAIN_0 = "gain0"
+    HIGH_GAIN_0 = "highgain0"
 
-    Jungfrau run gain settings was updated around the end of 2022
-    https://git.xfel.eu/karaboDevices/slsDetectors/-/commit/4433ae9c00edcca3309bec8b7515e0938f5f502c  # noqa
 
-    settings_lookup = {  # old setting:  new setting, new mode
-        "dynamicgain": ("gain0", "dynamic"),
-        "dynamichg0":  ("highgain0", "dynamic"),
-        "fixgain1": ("fixg1"),
-        "fixgain2": ("fixg2"),
-        "forceswitchg1": ("forceswitchg1"),
-        "forceswitchg2": ("forceswitchg2"),
-    }
-    """
+class JungfrauGainMode(Enum):
+    """Jungfrau run gain mode."""
     # old setting, new setting, new mode
-    DYNAMIC_GAIN = ("dynamicgain", "gain0", "dynamic")
-    DYNAMIC_GAIN_HG0 = ("dynamichg0", "highgain0", "dynamic")
-    # old setting, new mode
-    FIX_GAIN_1 = ("fixgain1", "fixg1")
-    FIX_GAIN_2 = ("fixgain2", "fixg2")
-    # old setting = new mode
+    DYNAMIC = "dynamic"
+    FIX_GAIN_1 = "fixg1"
+    FIX_GAIN_2 = "fixg2"
     FORCE_SWITCH_HG1 = "forceswitchg1"
     FORCE_SWITCH_HG2 = "forceswitchg2"
-
-    def __eq__(self, other):
-        return other in self.__dict__['_value_']
-
-    def __new__(cls, *values):
-        obj = object.__new__(cls)
-        for other_value in values:
-            cls._value2member_map_[other_value] = obj
-        obj._all_values = values
-        return obj
-        
-    def __repr__(self):
-        """Display all enum values."""
-        return "<%s.%s: %s>" % (
-                self.__class__.__name__,
-                self._name_,
-                ', '.join([repr(v) for v in self._all_values]),
-                )
diff --git a/src/cal_tools/jungfraulib.py b/src/cal_tools/jungfraulib.py
index 63ae544598348aba4954ebf993224d49fcc6dd6b..7f2923372ccd26ba138be6f084e69b272ef9320a 100644
--- a/src/cal_tools/jungfraulib.py
+++ b/src/cal_tools/jungfraulib.py
@@ -2,18 +2,30 @@ from typing import Optional, Tuple
 
 import extra_data
 
-from cal_tools.enums import JungfrauSettings
+from cal_tools.enums import JungfrauGainMode, JungfrauSettings
 
 
-def _get_settings(
-    run_dc: extra_data.DataCollection,
-    ctrl_src: str
-    ) -> Optional[str]:
-    """Get JUNGFRAU run settings."""
-    try:
-        return run_dc.get_run_value(ctrl_src, "settings")
-    except extra_data.PropertyNameError:
-        print("WARNING: \'settings.value\' key is not available for this run.")
+def _old_settings_to_new(settings, index):
+    """At the end of 2022, there is a sls update.
+    - `settings.value` values was updated from 6 possible values to only 2.
+    - `gainMode.value` dataset was created with 5 possible values.
+
+    https://git.xfel.eu/karaboDevices/slsDetectors/-/commit/4433ae9c00edcca3309bec8b7515e0938f5f502c  # noqa
+    
+    This method is used to get the settings or mode that
+    corresponds to old settings.value
+    """
+    settings_lookup = {
+        # old setting:  new setting, new mode
+        "dynamicgain": ("gain0", "dynamic"),
+        "dynamichg0":  ("highgain0", "dynamic"),
+        "fixgain1": ("gain0", "fixg1"),
+        "fixgain2": ("gain0", "fixg2"),
+        "forceswitchg1": ("gain0", "forceswitchg1"),
+        "forceswitchg2": ("gain0", "forceswitchg2"),
+    }
+    return settings_lookup[settings][index]
+
 
 class JungfrauCtrl():
     def __init__(
@@ -27,15 +39,28 @@ class JungfrauCtrl():
         """
         self.run_dc = run_dc
         self.ctrl_src = ctrl_src
-        self.run_settings = _get_settings(run_dc, ctrl_src)
+        # run settings and mode are read as raw settings
+        self.run_settings = self._get_settings()
         self.run_mode = self._get_mode()
 
+    def _get_settings(self) -> Optional[str]:
+        """Get JUNGFRAU run settings and mode."""
+        try:
+            settings = self.run_dc.get_run_value(self.ctrl_src, "settings")
+            if settings not in [m.value for m in JungfrauSettings]:
+                _old_settings_to_new(settings, 0)
+            return settings
+        except extra_data.PropertyNameError:
+            print("\'settings.value\' key "
+                  "is not available for this run.")
+
     def _get_mode(self) -> Optional[str]:
-        """Get JUNGFRAU run settings."""
-        try: # After Junfrau V5 (End of 2022) update `gainMode` is available.
+        """Get run mode from `gainMode` dataset."""
+        try:
             return self.run_dc.get_run_value(self.ctrl_src, "gainMode")
         except extra_data.PropertyNameError:
-            return self.run_settings
+            if self.run_settings is not None:
+                return _old_settings_to_new(self.run_settings, 1)
 
     def get_memory_cells(self) -> Tuple[int, int]:
         n_storage_cells = int(self.run_dc.get_run_value(
@@ -46,11 +71,10 @@ class JungfrauCtrl():
 
     def get_bias_voltage(self) -> int:
         """Get Bias voltage value from RUN source."""
-        # New keyname for bias voltage. After Jungfrau V5 (End of 2022) update.
         if "highVoltage" in self.run_dc[self.ctrl_src]:
             return int(
                 self.run_dc.get_run_value(self.ctrl_src, "highVoltage")[0])
-        else:  # Old key is "vHighVoltage" until 2022.
+        else:  # Old dataset "vHighVoltage" before end of 2022.
             return int(
                 self.run_dc.get_run_value(self.ctrl_src, "vHighVoltage")[0])
 
@@ -62,16 +86,10 @@ class JungfrauCtrl():
         """Get run gain settings to identify if run is in
         High CDS or Low CDS.
         """
-        gain_setting = 0  # e.g. For JungfrauSettings.DYNAMIC_GAIN
-        if self.run_settings == JungfrauSettings.DYNAMIC_GAIN_HG0:
-            gain_setting = 1
-        elif self.run_settings is None:
-             # Old RAW data didn't have the key `setting.value`
-            print("Setting \'gain_setting\' to 0, "
-                  "assuming that this is an old run. "
-                  f"\'settings.value\' = {self.run_settings}.\n")
-
-        return gain_setting
+        if self.run_settings == JungfrauSettings.HIGH_GAIN_0:
+            return 1
+        else:  # JungfrauSettings.GAIN_0
+            return 0
 
     def get_gain_mode(self) -> int:
         """From Jungfrau SW V5 gain_mode is deducted from
@@ -81,11 +99,10 @@ class JungfrauCtrl():
         if the value is 0 or 1.
         Gain Mode is fixed (1) if the enum is fixg1 or fixg2.
         """
-
-        if (
-            self.run_mode == JungfrauSettings.FIX_GAIN_1 or
-            self.run_mode == JungfrauSettings.FIX_GAIN_2
-            ):
+        if self.run_mode in [
+            JungfrauGainMode.FIX_GAIN_1.value,
+            JungfrauGainMode.FIX_GAIN_2.value,
+        ]:
             return 1
-        else:
+        else:  # DYNAMIC, FORCE_SWITCH_G1, or FORCE_SWITCH_G2
             return 0